import pandas
import numpy as np
import sklearn.linear_model
import matplotlib.pyplot as plt


climate = pandas.read_csv('https://www.cl.cam.ac.uk/teaching/2021/DataSci/data/climate.csv')
climate['t'] = climate.yyyy + (climate.mm-1)/12
climate['temp'] = (climate.tmin + climate.tmax)/2

df = climate.loc[(climate.station=='Cambridge') & (~pandas.isna(climate.temp))]
t, temp = df['t'], df['temp']

X = np.column_stack([
    (t - 1980) * np.where(t >= 1980, 1, 0),
    (t - 1980) * np.where(t < 1980, 1, 0)
])
model = sklearn.linear_model.LinearRegression(fit_intercept=True)
model.fit(X, temp)

_, ax = plt.subplots(figsize=(8, 5))
ax.plot(t, model.predict(X), color='r')
ax.plot(t, temp)
ax.set_xlabel("Year")
ax.set_ylabel("Temperature in Celsius")
plt.tight_layout()
plt.savefig('ex15_cam_plot.pdf')
plt.show()
