import pandas
import numpy as np
import sklearn.linear_model
import matplotlib.pyplot as plt


climate = pandas.read_csv('https://www.cl.cam.ac.uk/teaching/2021/DataSci/data/climate.csv')
climate['t'] = climate.yyyy + (climate.mm-1)/12
climate['temp'] = (climate.tmin + climate.tmax)/2

# Let's look at Oxford, which has longer records.
df = climate.loc[(climate.station=='Oxford') & (~pandas.isna(climate.temp))]
t,temp = df['t'], df['temp']
d = np.floor(t/10).astype(int) * 10

# Plotting is better if we work with integers for decades, not strings!
decades = np.sort(np.unique(d))
X = [np.sin(2 * np.pi * t), np.cos(2 * np.pi * t)] + [np.where(d==i, 1, 0) for i in decades]
model = sklearn.linear_model.LinearRegression(fit_intercept=False)
model.fit(np.column_stack(X), temp)

# Use Python's magic sequence‐unpacking syntax: gamma is a LIST of remaining coefs
b1, b2, *gamma = model.coef_

_, ax = plt.subplots(figsize=(4, 2.5))
ax.step(decades, gamma, where='post')
ax.set_xlabel("Decade")
ax.set_ylabel("$\\gamma_d$")
plt.show()
